==> php-residence_0.2.4.tar.gz: php-residence/includes/lang/en/modifica_app.php <==
<?php

switch ($messaggio) {

case "L'appartamento":  			$messaggio = "The apartment"; break;
case "contiene prenotazione future, non si pu cancellare":	$messaggio = "contains reservations in the future, it can't be deleted"; break;
case " gi stato cancellato":  		$messaggio = "has already been deleted"; break;
case "Sei sicuro di voler <b>cancellare</b> l'appartamento":	$messaggio = "Are you sure you want to <b>delete</b> apartment"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case " stato cancellato":  			$messaggio = "has been deleted"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "La casa verr cambiata da":  		$messaggio = "The house will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "Il piano verr cambiato da":  		$messaggio = "The floor will be changed from"; break;
case "Il massimo numero di occupanti verr cambiato da":	$messaggio = "The maximum number of people that it can host will be changed from"; break;
case "La priorit verr cambiata da":  		$messaggio = "The priority will be changed from"; break;
case "Il commento verr cambiato":  		$messaggio = "The comment will be changed"; break;
case "Continua":  				$messaggio = "Continue"; break;
case " stato modificato":  			$messaggio = "has been modified"; break;
case "Modifica l'appartamento":  		$messaggio = "Modify apartment"; break;
case "Casa":  					$messaggio = "House"; break;
case "Cambia in":  				$messaggio = "Change to"; break;
case "Piano":  					$messaggio = "Floor"; break;
case "Capienza":  				$messaggio = "Capacity"; break;
case "Priorit":  				$messaggio = "Priority"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Persone":  				$messaggio = "People"; break;
case "<b>Attenzione</b>: le prenotazioni gi inserite in questo appartamento <b>non</b> verranno spostate":	$messaggio = "<b>Warning</b>: the reservations already inserted in this apartment will <b>not</b> be moved"; break;
case "anche se le loro caratteristiche non sono pi compatibili":	$messaggio = "even if their characteristics are not compatible anymore"; break;
case "Cancella l'appartamento":  		$messaggio = "Delete apartment"; break;
case "Nome":  		$messaggio = "Name"; break;
case "Il nome dell'appartamento verr cambiato da":	$messaggio = "The apartment name will be changed from"; break;
case "esiste gi":  				$messaggio = "already exists"; break;
case "non esiste pi":  			$messaggio = "does not exist any more"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> php-residence_0.4.3.tar.gz: php-residence/includes/lang/en/modifica_app.php <==
<?php

switch ($messaggio) {

case "L'appartamento":  			$messaggio = "The apartment"; break;
case "contiene prenotazione future, non si pu cancellare":	$messaggio = "contains reservations in the future, it can't be deleted"; break;
case " gi stato cancellato":  		$messaggio = "has already been deleted"; break;
case "Sei sicuro di voler <b>cancellare</b> l'appartamento":	$messaggio = "Are you sure you want to <b>delete</b> apartment"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case " stato cancellato":  			$messaggio = "has been deleted"; break;
case "Torna indietro":  			$messaggio = "Go back"; break;
case "La casa verr cambiata da":  		$messaggio = "The house will be changed from"; break;
case "a":  					$messaggio = "to"; break;
case "Il piano verr cambiato da":  		$messaggio = "The floor will be changed from"; break;
case "Il massimo numero di occupanti verr cambiato da":	$messaggio = "The maximum number of people that it can host will be changed from"; break;
case "La priorit verr cambiata da":  		$messaggio = "The priority will be changed from"; break;
case "Il commento verr cambiato":  		$messaggio = "The comment will be changed"; break;
case "Continua":  				$messaggio = "Continue"; break;
case " stato modificato":  			$messaggio = "has been modified"; break;
case "Modifica l'appartamento":  		$messaggio = "Modify apartment"; break;
case "Casa":  					$messaggio = "House"; break;
case "Cambia in":  				$messaggio = "Change to"; break;
case "Piano":  					$messaggio = "Floor"; break;
case "Capienza":  				$messaggio = "Capacity"; break;
case "Priorit":  				$messaggio = "Priority"; break;
case "Commento":  				$messaggio = "Comment"; break;
case "Persone":  				$messaggio = "People"; break;
case "<b>Attenzione</b>: le prenotazioni gi inserite in questo appartamento <b>non</b> verranno spostate":	$messaggio = "<b>Warning</b>: the reservations already inserted in this apartment will <b>not</b> be moved"; break;
case "anche se le loro caratteristiche non sono pi compatibili":	$messaggio = "even if their characteristics are not compatible anymore"; break;
case "Cancella l'appartamento":  		$messaggio = "Delete apartment"; break;
case "Nome":  		$messaggio = "Name"; break;
case "Il nome dell'appartamento verr cambiato da":	$messaggio = "The apartment name will be changed from"; break;
case "esiste gi":  				$messaggio = "already exists"; break;
case "non esiste pi":  			$messaggio = "does not exist any more"; break;
case "<b>L'appartamento non  stato cancellato</b> perch il database  cambiato nel frattempo":	$messaggio = "<b>The apartment has not been deleted</b> because the database has been modified meanwhile"; break;
case "<b>L'appartamento non  stato modificato</b> perch il database  cambiato nel frattempo":	$messaggio = "<b>The apartment has not been modified</b> because the database has been modified meanwhile"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
